package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcTitleEval;

/**
 * 职称评审Mapper接口
 * 
 * @author cmc
 * @date 2025-08-18
 */
public interface CmcTitleEvalMapper 
{
    /**
     * 查询职称评审
     * 
     * @param titleEvalId 职称评审主键
     * @return 职称评审
     */
    public CmcTitleEval selectCmcTitleEvalByTitleEvalId(String titleEvalId);

    /**
     * 查询职称评审列表
     * 
     * @param cmcTitleEval 职称评审
     * @return 职称评审集合
     */
    public List<CmcTitleEval> selectCmcTitleEvalList(CmcTitleEval cmcTitleEval);

    /**
     * 新增职称评审
     * 
     * @param cmcTitleEval 职称评审
     * @return 结果
     */
    public int insertCmcTitleEval(CmcTitleEval cmcTitleEval);

    /**
     * 修改职称评审
     * 
     * @param cmcTitleEval 职称评审
     * @return 结果
     */
    public int updateCmcTitleEval(CmcTitleEval cmcTitleEval);

    /**
     * 删除职称评审
     * 
     * @param titleEvalId 职称评审主键
     * @return 结果
     */
    public int deleteCmcTitleEvalByTitleEvalId(String titleEvalId);

    /**
     * 批量删除职称评审
     * 
     * @param titleEvalIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcTitleEvalByTitleEvalIds(String[] titleEvalIds);
}
